.. raw :: html

    <!-- Generated by generate_authors_table.py -->
    <div class="sk-authors-container">
    <style>
      img.avatar {border-radius: 10px;}
    </style>
    <div>
    <a href='https://github.com/jeremiedbb'><img src='https://avatars.githubusercontent.com/u/34657725?v=4' class='avatar' /></a> <br />
    <p>Jérémie du Boisberranger</p>
    </div>
    <div>
    <a href='https://github.com/lesteve'><img src='https://avatars.githubusercontent.com/u/1680079?v=4' class='avatar' /></a> <br />
    <p>Loïc Estève</p>
    </div>
    <div>
    <a href='https://github.com/thomasjpfan'><img src='https://avatars.githubusercontent.com/u/5402633?v=4' class='avatar' /></a> <br />
    <p>Thomas J. Fan</p>
    </div>
    <div>
    <a href='https://github.com/agramfort'><img src='https://avatars.githubusercontent.com/u/161052?v=4' class='avatar' /></a> <br />
    <p>Alexandre Gramfort</p>
    </div>
    <div>
    <a href='https://github.com/ogrisel'><img src='https://avatars.githubusercontent.com/u/89061?v=4' class='avatar' /></a> <br />
    <p>Olivier Grisel</p>
    </div>
    <div>
    <a href='https://github.com/betatim'><img src='https://avatars.githubusercontent.com/u/1448859?v=4' class='avatar' /></a> <br />
    <p>Tim Head</p>
    </div>
    <div>
    <a href='https://github.com/NicolasHug'><img src='https://avatars.githubusercontent.com/u/1190450?v=4' class='avatar' /></a> <br />
    <p>Nicolas Hug</p>
    </div>
    <div>
    <a href='https://github.com/adrinjalali'><img src='https://avatars.githubusercontent.com/u/1663864?v=4' class='avatar' /></a> <br />
    <p>Adrin Jalali</p>
    </div>
    <div>
    <a href='https://github.com/jjerphan'><img src='https://avatars.githubusercontent.com/u/13029839?v=4' class='avatar' /></a> <br />
    <p>Julien Jerphanion</p>
    </div>
    <div>
    <a href='https://github.com/glemaitre'><img src='https://avatars.githubusercontent.com/u/7454015?v=4' class='avatar' /></a> <br />
    <p>Guillaume Lemaitre</p>
    </div>
    <div>
    <a href='https://github.com/adam2392'><img src='https://avatars.githubusercontent.com/u/3460267?v=4' class='avatar' /></a> <br />
    <p>Adam Li</p>
    </div>
    <div>
    <a href='https://github.com/lucyleeow'><img src='https://avatars.githubusercontent.com/u/23182829?v=4' class='avatar' /></a> <br />
    <p>Lucy Liu</p>
    </div>
    <div>
    <a href='https://github.com/lorentzenchr'><img src='https://avatars.githubusercontent.com/u/15324633?v=4' class='avatar' /></a> <br />
    <p>Christian Lorentzen</p>
    </div>
    <div>
    <a href='https://github.com/amueller'><img src='https://avatars.githubusercontent.com/u/449558?v=4' class='avatar' /></a> <br />
    <p>Andreas Mueller</p>
    </div>
    <div>
    <a href='https://github.com/jnothman'><img src='https://avatars.githubusercontent.com/u/78827?v=4' class='avatar' /></a> <br />
    <p>Joel Nothman</p>
    </div>
    <div>
    <a href='https://github.com/OmarManzoor'><img src='https://avatars.githubusercontent.com/u/17495884?v=4' class='avatar' /></a> <br />
    <p>Omar Salman</p>
    </div>
    <div>
    <a href='https://github.com/GaelVaroquaux'><img src='https://avatars.githubusercontent.com/u/208217?v=4' class='avatar' /></a> <br />
    <p>Gael Varoquaux</p>
    </div>
    <div>
    <a href='https://github.com/Charlie-XIAO'><img src='https://avatars.githubusercontent.com/u/108576690?v=4' class='avatar' /></a> <br />
    <p>Yao Xiao</p>
    </div>
    <div>
    <a href='https://github.com/Micky774'><img src='https://avatars.githubusercontent.com/u/34613774?v=4' class='avatar' /></a> <br />
    <p>Meekail Zain</p>
    </div>
    </div>
